@@ -1,8 +1,10 @@
 """Print to stdout with colour."""
 from __future__ import annotations
 
+import sys
 from typing import List
 from typing import Optional
+from typing import TextIO
 from typing import Union
 
 from colourout.process_styles import process_styles
@@ -14,6 +16,7 @@ def printc(
     sep: str = " ",
     end: str = "\n",
     styles: Optional[List[Union[Styles, str]]] = None,
+    file: Optional[TextIO] = None,
 ) -> None:
     r"""
     Print with colour.
@@ -38,9 +41,11 @@ def printc(
     >>> printc("Hello, world!", styles=["BLUE", "ITALIC"])
     \033[94m\033[3mHello, world!\033[0m
     """
+    file = file if file is not None else sys.stdout
+
     styles = styles or [Styles.END]
     processed_styles = process_styles(styles)
 
-    print(*processed_styles, sep="", end="")
-    print(*__values, sep=sep, end=end)
-    print(Styles.END.value, end="")
+    print(*processed_styles, sep="", end="", file=file)
+    print(*__values, sep=sep, end="", file=file)
+    print(Styles.END.value, end=end, file=file)
